API docs for “spamfighter.core.commands.test.test_partner.DomainedCommandTestCase”

# Class s.c.c.t.t.DomainedCommandTestCase(unittest.TestCase):

Part of spamfighter.core.commands.test.test_partner View Source View In Hierarchy

Тест на `spamfighter.core.commands.partner.DomainedCommand`.

Method | setUp | Undocumented
Method | testDomainOk | Undocumented
Method | testDomainFail | Undocumented

def setUp(self): (source)
Undocumented
def testDomainOk(self): (source)
Undocumented
def testDomainFail(self): (source)
Undocumented